==> geonkick_2.10.2.orig.tar.gz: geonkick-2.10.2/src/general_envelope.h <==
/**
 * File name: general_envelope.h
 * Project: Geonkick (A kick synthesizer)
 *
 * Copyright (C) 2017 Iurie Nistor
 *
 * This file is part of Geonkick.
 *
 * GeonKick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GKICK_GENERAL_ENVELOPE_H
#define GKICK_GENERAL_ENVELOPE_H

#include "envelope.h"

class Oscillator;
class GeonkickApi;

class GeneralEnvelope: public Envelope
{
 public:

  GeneralEnvelope(GeonkickApi *api, const RkRect &area);
  double envelopeLength(void) const final;
  void setEnvelopeLengh(double len) final;
  void updatePoints() final;

 protected:
  void pointAddedEvent(double x, double y) final;
  void pointUpdatedEvent(unsigned int index, double x, double y) final;
  void pointRemovedEvent(unsigned int index) final;
  double envelopeAmplitude(void) const final;

 private:
          GeonkickApi *geonkickApi;
};

#endif

==> geonkick_3.5.2.orig.tar.gz: geonkick-3.5.2/src/general_envelope.h <==
/**
 * File name: general_envelope.h
 * Project: Geonkick (A kick synthesizer)
 *
 * Copyright (C) 2017 Iurie Nistor
 *
 * This file is part of Geonkick.
 *
 * GeonKick is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GKICK_GENERAL_ENVELOPE_H
#define GKICK_GENERAL_ENVELOPE_H

#include "envelope.h"

class Oscillator;
class GeonkickApi;

class GeneralEnvelope: public Envelope
{
 public:

  GeneralEnvelope(GeonkickApi *api, const RkRect &area);
  double envelopeLength(void) const override;
  void setEnvelopeLengh(double len) override;
  void updateEnvelope() override;
  void updatePoints() override;

 protected:
  void pointAddedEvent(double x, double y) override;
  void pointUpdatedEvent(unsigned int index, double x, double y) override;
  void pointRemovedEvent(unsigned int index) override;
  double envelopeAmplitude(void) const override;

 private:
          GeonkickApi *geonkickApi;
};

#endif
